@@ -282,11 +282,11 @@ sub regex {
 	}x;
 	$re .= qr{
 		(?:
-			rt=([\d\.]+)   # request time [12]
+			\srt=([\d\.]+)   # request time [12]
 				|
-			ut="([^"]+)"   # upstream response time [13]
+			\sut="([^"]+)"   # upstream response time [13]
 				|
-			cs=(\S+)       # upstream cache status [14]
+			\scs=(\S+)       # upstream cache status [14]
 				|
 			.
 		)*
